## cwbplot: Useful tools for meteorology data

There are several useful tools for meteorology data visualization and data processing in this package.


This package includes

 * Tools for CWB rfs team daily work  
 * CWB open data (https://opendata.cwb.gov.tw/index) IO and visualization
 * Others


這個套件包含

 * 氣象局區域模式小組日常工作工具
 * 氣象局開放資料(https://opendata.cwb.gov.tw/index) 讀取及視覺化
 * 其它

Documentation: https://cwbplot.readthedocs.io/en/dev/index.html

參考文件: https://cwbplot.readthedocs.io/en/dev/index.html
